@@ -41,10 +41,11 @@ sub my_options {
 	     'range to be clipped.'
 	    ],
 	 graph_type => [
-	     ['histogram','boxes','line','points','linepoints'],
-	     'histogram',
-	     'Type of graph to generate. Options are "histogram", "boxes",',
-	     '"line","points", or "linepoints".'
+	     ['boxes','line','points','linepoints'],
+	     'boxes',
+	     'Type of graph to generate. Options are "boxes",',
+	     '"line","points", or "linepoints".',
+	     'The deprecated "histogram" subtype is equivalent to "boxes".'
 	     ],
 	 point_symbol => [
 	     'string',
@@ -148,6 +149,7 @@ sub graph_type {
 sub draw {
   my $self = shift;
   my ($gd,$dx,$dy) = @_;
+
   my ($left,$top,$right,$bottom) = $self->calculate_boundaries($dx,$dy);
   my @parts = $self->parts;
 
@@ -196,6 +198,7 @@ sub draw {
 
   $self->panel->startGroup($gd);
   $self->_draw_grid($gd,$scale,$min_score,$max_score,$dx,$dy,$y_origin);
+
   $self->panel->endGroup($gd);
 
   for my $draw_method (@draw_methods) {
@@ -206,8 +209,9 @@ sub draw {
   $self->_draw_scale($gd,$scale,$min_score,$max_score,$dx,$dy,$y_origin);
   $self->panel->endGroup($gd);
 
-  $self->draw_label(@_)       if $self->option('label');
-  $self->draw_description(@_) if $self->option('description');
+  $self->draw_label(@_)       if ($self->option('label') && !$self->option('overlay'));
+  $self->draw_description(@_) if ($self->option('description') && !$self->option('overlay'));
+  $self->draw_legend(@_)      if $self->option('overlay');
 
   $self->panel->endGroup($gd);
 }
@@ -216,7 +220,7 @@ sub lookup_draw_method {
   my $self = shift;
   my $type = shift;
 
-  return '_draw_histogram'            if $type eq 'histogram';
+  return '_draw_boxes'                if $type eq 'histogram';  # same thing
   return '_draw_boxes'                if $type eq 'boxes';
   return qw(_draw_line _draw_points)  if $type eq 'linepoints';
   return '_draw_line'                 if $type eq 'line';
@@ -279,40 +283,40 @@ sub min10 {
   return $l*int($a/$l);
 }
 
-sub _draw_histogram {
-  my $self = shift;
-  my ($gd,$left,$top,$bottom) = @_;
+# sub _draw_histogram {
+#   my $self = shift;
+#   my ($gd,$left,$top,$bottom) = @_;
 
-  my @parts   = $self->parts;
-  my $fgcolor = $self->fgcolor;
+#   my @parts   = $self->parts;
+#   my $fgcolor = $self->fgcolor;
 
-  # draw each of the component lines of the histogram surface
-  for (my $i = 0; $i < @parts; $i++) {
-    my $part = $parts[$i];
-    my $next = $parts[$i+1];
-    my ($x1,$y1,$x2,$y2) = $part->calculate_boundaries($left,$top);
-    next unless defined $part->{_y_position};
-    $gd->line($x1,$part->{_y_position},$x2,$part->{_y_position},$fgcolor);
-    next unless $next;
-    my ($x3,$y3,$x4,$y4) = $next->calculate_boundaries($left,$top);
-    if ($x2 == $x3) {# connect vertically to next level
-      $gd->line($x2,$part->{_y_position},$x2,$next->{_y_position},$fgcolor); 
-    } else {
-      $gd->line($x2,$part->{_y_position},$x2,$bottom,$fgcolor); # to bottom
-      $gd->line($x2,$bottom,$x3,$bottom,$fgcolor);              # to right
-      $gd->line($x3,$bottom,$x3,$next->{_y_position},$fgcolor); # up
-    }
-  }
+#   # draw each of the component lines of the histogram surface
+#   for (my $i = 0; $i < @parts; $i++) {
+#     my $part = $parts[$i];
+#     my $next = $parts[$i+1];
+#     my ($x1,$y1,$x2,$y2) = $part->calculate_boundaries($left,$top);
+#     next unless defined $part->{_y_position};
+#     $gd->line($x1,$part->{_y_position},$x2,$part->{_y_position},$fgcolor);
+#     next unless $next;
+#     my ($x3,$y3,$x4,$y4) = $next->calculate_boundaries($left,$top);
+#     if ($x2 == $x3) {# connect vertically to next level
+#       $gd->line($x2,$part->{_y_position},$x2,$next->{_y_position},$fgcolor); 
+#     } else {
+#       $gd->line($x2,$part->{_y_position},$x2,$bottom,$fgcolor); # to bottom
+#       $gd->line($x2,$bottom,$x3,$bottom,$fgcolor);              # to right
+#       $gd->line($x3,$bottom,$x3,$next->{_y_position},$fgcolor); # up
+#     }
+#   }
 
-  # end points: from bottom to first
-  my ($x1,$y1,$x2,$y2) = $parts[0]->calculate_boundaries($left,$top);
-  $gd->line($x1,$bottom,$x1,$parts[0]->{_y_position},$fgcolor);
-  # from last to bottom
-  my ($x3,$y3,$x4,$y4) = $parts[-1]->calculate_boundaries($left,$top);
-  $gd->line($x4,$parts[-1]->{_y_position},$x4,$bottom,$fgcolor);
+#   # end points: from bottom to first
+#   my ($x1,$y1,$x2,$y2) = $parts[0]->calculate_boundaries($left,$top);
+#   $gd->line($x1,$bottom,$x1,$parts[0]->{_y_position},$fgcolor);
+#   # from last to bottom
+#   my ($x3,$y3,$x4,$y4) = $parts[-1]->calculate_boundaries($left,$top);
+#   $gd->line($x4,$parts[-1]->{_y_position},$x4,$bottom,$fgcolor);
 
-  # That's it.  Not too hard.
-}
+#   # That's it.  Not too hard.
+# }
 
 sub _draw_boxes {
   my $self = shift;
@@ -320,8 +324,9 @@ sub _draw_boxes {
 
   my @parts    = $self->parts;
   my $lw       = $self->linewidth;
-  my $positive = $self->pos_color;
-  my $negative = $self->neg_color;
+  # Make the boxes transparent
+  my $positive = $self->pos_color + 1073741824;
+  my $negative = $self->neg_color + 1073741824;
   my $height   = $self->height;
 
   my $midpoint = $self->midpoint ? $self->score2position($self->midpoint) 
@@ -335,7 +340,7 @@ sub _draw_boxes {
 
     my $part = $parts[$i];
     my $next = $parts[$i+1];
-
+	
     my ($color,$negcolor);
 
     # special check here for the part_color being defined so as not to introduce lots of
@@ -376,7 +381,8 @@ sub _draw_line {
   my $current_x = ($x1+$x2)/2;
   my $current_y = $first_part->{_y_position};
 
-  for my $part (@parts) {
+  for my $part (@parts) {  
+    
     ($x1,$y1,$x2,$y2) = $part->calculate_boundaries($left,$top);
     my $next_x = ($x1+$x2)/2;
     my $next_y = $part->{_y_position};
@@ -658,6 +664,25 @@ sub draw_label {
 		      $label);
 }
 
+sub draw_legend {
+  my $self = shift;
+  my ($gd,$left,$top,$partno,$total_parts) = @_;
+  my $color = $self->option('fgcolor'); 
+  my $name = $self->feature->{name};
+
+  my $label = "<a id=\"legend_$name\" target=\"_blank\" href=\"#\"> <font color=\'$color\';\">" . $name . "</font></a>" or return;
+
+  my $font = $self->labelfont;
+  my $x = $self->left + $left - $font->width*length($label) - $self->extra_label_pad;
+  my $y = $self->{top} + $top;
+  my $is_legend = 1;
+  $self->render_label($gd,
+		      $font,
+		      $x,
+		      $y,
+		      $label,
+		      $is_legend);
+}
 
 1;
 
